@@ -3,7 +3,7 @@ class Irradiance():
   def __init__(self, url:str="https://raw.githubusercontent.com/fabio-r-almeida/pvmodule/main/Albedo.csv"):
     self.url = 'https://raw.githubusercontent.com/fabio-r-almeida/pvmodule/main/Albedo.csv'
 
-  def _get_TMY(self, location, panel_tilt:float, azimuth:float, startyear:int=2020, endyear:int=2020 ):
+  def _get_TMY(self, module, location, panel_tilt:float, azimuth:float, _month, startyear:int=2020, endyear:int=2020 ):
 
     """
     This method gets from PVGIS the necessary data using the TMY.
@@ -41,110 +41,70 @@ class Irradiance():
     #SP: Surface (air) pressure (Pa)
 
     #month 	G(i) 	Gb(i) 	Gd(i) 	G(n) 	Gb(n) 	Gd(n) 	T2m 	WS10m
-    global df_res
-    global inputs
-    global metadata
-    df_res = pd.DataFrame()
-    def get_data(i):
-      global inputs
-      global metadata
-      global df_res
-      inputs, data , metadata = PVGIS().retrieve_daily(
-                    location.latitude, 
-                    location.longitude, 
-                    month= i, 
-                    angle = 0, 
-                    aspect = azimuth, 
-                    glob_2axis = 1)
 
-      df_res=  pd.concat([df_res, data])
+    if module['BIPV'] == 'Y' and panel_tilt > 80:
+      inputs, data1 , metadata = PVGIS().retrieve_daily(
+                        location.latitude, 
+                        location.longitude, 
+                        month= _month, 
+                        angle = panel_tilt, 
+                        aspect = azimuth*-1, 
+                        glob_2axis = 1)
+      
+      inputs2, data2 , metadata2 = PVGIS().retrieve_daily(
+                        location.latitude, 
+                        location.longitude, 
+                        month= _month, 
+                        angle = panel_tilt, 
+                        aspect = azimuth, 
+                        glob_2axis = 1)
+      
+      data = data1.add(data2, fill_value=0)
       
-      #df_res = df_res.concat(data)
 
-    threads = []
-    for i in range(1,13):
-      t1 = Thread(target=get_data, args=(i,))
-      threads.append(t1)
-
-    # Start all threads
-    for x in threads:
-        x.start()
-
-    # Wait for all of them to finish
-    for x in threads:
-            print(f'done: {x}')
-            x.join()
-
-    print("exit threads")
-    data = df_res.sort_values(by=['month'])
-    
-
-    data.rename(columns = {'G(i)':'GHI',
-                           'Gb(i)':'DHI',
-                           'Gb(n)':'DNI',
-                           'T2m':'2m Air Temperature',
-                           'WS10m':'10m Wind speed'
-                          }, inplace = True)
-    
-
-
-    df_date = pd.DataFrame()
-    df_date['date'] = pd.date_range(f"{2030}-01-01 00:00:00", f"{2030}-12-31 23:00:00", freq='5T').to_frame()
-    data =  data.rename_axis('time').sort_values(by = ['month', 'time'], ascending = [True, True])
-
-
-    data['Time'] = pd.to_datetime(data.index).time
-
-    print("logic 1")
-
-
-    df_date['Time'] = pd.to_datetime(df_date['date']).dt.time
-    df_date['Day'] = df_date.index.day
-    df_date['Month'] = df_date.index.month
-
-    final_df = pd.merge(data, df_date, how = 'inner', left_on = ['Time','month'], right_on = ['Time','Month'])
-    final_df.index = final_df['date']
-    final_df = final_df.sort_index()
-
-    df_both = pd.date_range(f"{2030}-01-01 00:00:00", f"{2030}-12-31 23:00:00", freq='5T').to_frame()
-    df_both = df_both.drop([0], axis=1)
-    final_df = df_both.merge(final_df, left_index=True, right_index=True, how='left')
-
-
-    
-
-
-    print("logic 2")
+    else:
+      inputs, data , metadata = PVGIS().retrieve_daily(
+                        location.latitude, 
+                        location.longitude, 
+                        month= _month, 
+                        angle = panel_tilt, 
+                        aspect = azimuth, 
+                        glob_2axis = 1)
 
         
-    final_df['Time_H'] = final_df.index.strftime("%H").astype(float)
-    final_df['Time_M'] = final_df.index.strftime("%M").astype(float)
-    final_df['Time_S'] = final_df.index.strftime("%S").astype(float)
 
-    final_df['Month']= final_df['Month'].fillna(method='ffill')
-    final_df['Day']= final_df['Day'].fillna(method='ffill')
-    final_df = final_df.drop(['date','Time','Gd(i)','G(n)','Gd(n)'], axis=1)
-
-  
-    data = final_df
-
-    data = data.interpolate(method='polynomial', order=2)
-    data['DHI'] = data['DHI'].round(0)
-    data['GHI'] = data['GHI'].round(0)
-    data['DNI'] = data['DNI'].round(0)
+    data.rename(columns = {'G(i)':'GHI',
+                              'Gb(i)':'DHI',
+                              'Gb(n)':'DNI',
+                              'T2m':'2m Air Temperature',
+                              'WS10m':'10m Wind speed'
+                              }, inplace = True)
 
 
 
+    import pandas as pd
+    #data['Time'] = pd.to_datetime(data.index).time
+    #data.index = data['Time']
 
+    data.index = pd.to_datetime(data.index).strftime('%H:%M:%S')
 
+    data.index = pd.DatetimeIndex(data.index)
+    data['Time_H'] = data.index.strftime("%H").astype(float)
+    data['Time_M'] = data.index.strftime("%M").astype(float)
+    data['Time_S'] = data.index.strftime("%S").astype(float)
+
+    data = data.drop(['Gd(i)','G(n)','Gd(n)'], axis=1)
+
+    
+    data['day'] = data.index.values.astype('datetime64[Y]')
+    data.index = data['day'].values.astype('datetime64[M]') + _month - 1
 
-    print("logic 3")
     DOY =  pd.DatetimeIndex(data.index.values).day_of_year
     data['Declination'] = (23.45*np.sin(np.deg2rad((360/365)*(284+DOY)))).values
 
     omega = abs((data['Time_H']*60+data['Time_M']+data['Time_S']/60)/4 - 180)
     
-    data = data.drop(['Time_H', 'Time_M','Time_S'], axis=1)
+    data = data.drop(['Time_M','Time_S','day'], axis=1)
 
     data['Hour angle'] = omega
 
@@ -191,9 +151,9 @@ class Irradiance():
 
 
 
-  def irradiance(self, module, location, panel_tilt:float=35, albedo:float=0.2, azimuth:float = 0, Elevation=2, panel_distance:float = None):
+  def irradiance(self, module, location,_month, panel_tilt:float=35, albedo:float=0.2, azimuth:float = 0, Elevation=2, panel_distance:float = None):
 
-    inputs ,data, metadata = Irradiance()._get_TMY(location, panel_tilt, azimuth)
+    inputs ,data, metadata = Irradiance()._get_TMY(module, location, panel_tilt, azimuth, _month=_month)
 
 
     if panel_distance == None:
@@ -209,9 +169,8 @@ class Irradiance():
       data['Total_G'] = G_front
       data[['GHI', 'DHI','DNI','G_Front','Total_G']] = data[['GHI', 'DHI','DNI','G_Front','Total_G']].clip(lower=0)
       data['Total_G'] = data['Total_G'].round(0)
+      data['G_Rear'] = 0
       #data = data.drop(['Declination', 'Hour angle','Rb_front','Rb_rear','Solar Zenith angle','GHI','DNI','DHI','2m Air Temperature','10m Wind speed'], axis=1)
-
-
       return inputs ,data, metadata
 
 
